pynessie package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pynessie.auth
   pynessie.conf

Submodules
----------

pynessie.cli module
-------------------

.. automodule:: pynessie.cli
   :members:
   :undoc-members:
   :show-inheritance:

pynessie.error module
---------------------

.. automodule:: pynessie.error
   :members:
   :undoc-members:
   :show-inheritance:

pynessie.model module
---------------------

.. automodule:: pynessie.model
   :members:
   :undoc-members:
   :show-inheritance:

pynessie.nessie\_client module
------------------------------

.. automodule:: pynessie.nessie_client
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pynessie
   :members:
   :undoc-members:
   :show-inheritance:
